## What

<!-- 1-3 sentences. Link the issue if there is one. -->

## AI Provenance

<!-- Remove this section for human-authored PRs. -->

- **Tool:** <!-- Claude Code, Cursor, Copilot, Codex, etc. -->
- **Model:** <!-- Claude Opus 4.6, GPT-4o, etc. -->
- **Prompt/thread:** <!-- Paste your prompt or a link to the thread. -->

## Checklist

- [ ] Addresses exactly one issue or feature
- [ ] New or changed behavior has test coverage
- [ ] Diff contains only changes for this task
